# pandashare

Sharing data focused on financial AI.

## Installation

You can install this package via pip:

pip install pandashare


## Usage

```python
from pandashare import greet

print(greet('World'))

import pandashare as ps


